@@ -32,7 +32,7 @@ setMethod(
     .Object@spacing   <- spacing
     #Check object is valid
     valid <- try(validObject(.Object), silent = TRUE)
-    if(class(valid) == "try-error"){
+    if(inherits(valid, "try-error")){
       stop(attr(valid, "condition")$message, call. = FALSE)
     }
     # return object
